#*************************************************************
# Progamm:			absorption
# Sinn des Programms: 		Berechnung der Absorption in einer homogenen Schicht
# Sinn der Einheit  :		Hauptprogramm	
# Name dieser Datei:		absorption_1d_haupt.py
# Versionsnummer:		1
# Wird aufgerufen von:		-
# Ruft auf:			zeit.py, steuer.py, gitter.py, rechner.py, ausgabe.py
# Nummer im Programmpaket:	1
# von:				6			
# Autor: 			Armin Ulrich
# Erster Lauf: 			12.07.2018
# Letzte Änderung: 		14.01.2020
#*************************************************************

#*************************************************************
# Importieren der Klassen zur Zeitdokumentation
#*************************************************************
import time
import datetime

	
#*************************************************************
# Importieren der Klassen
#*************************************************************


from steuer import Steuer
from gitter import Gitter
from rechner import Rechner
from ausgabe import Ausgabe

#*************************************************************
# Belegung der Klassen
#*************************************************************

steuer = Steuer()
gitter = Gitter()
rechner = Rechner()
ausgabe = Ausgabe()

#*************************************************************
# Berechnung der Startzeit des Programmes mit:
# a) datetime
# b) time
# und Konvertieren der Startzeit zu einem String "datum_zeit"
#*************************************************************
dt_start = datetime.datetime.now()
lt_start = time.localtime()
jahr, monat, tag, stunde, minute, sekunde  = lt_start[0:6]
datum_zeit = "Datum: " +str(tag)+"."+str(monat)+"."+str(jahr)+"\n"+"Zeit: "+str(stunde)+":"+str(minute)+":"+str(sekunde)

#*************************************************************
# Ausgabe an
#*************************************************************
print("Absorption")
print("1d, stationär")


#*************************************************************
# öffnen der Log-Datei
#*************************************************************
fobj_log = open("absorption.log","w")

#*************************************************************
# Schreiben von Datum und Zeit des Programmstarts 
# in die Logdatei 
#*************************************************************
fobj_log.write("Anfang: "+ "\n" + datum_zeit)
fobj_log.write("\n")


#*************************************************************
# Prüfung, ob Steuerdatei erfolgreich geöffnet wurde
#*************************************************************
if(steuer.steuer_input()):
  fobj_log.write( "Datei existiert\n")
else:
  fobj_log.write( "Datei existiert nicht\n")

#*************************************************************
# Einlesen des Gitters
#*************************************************************
gitter.gitter_input(steuer.gitter_datei)

rechner.euler(steuer.Intens_init, steuer.kappa, gitter.i_max, gitter.x, gitter.delta_x)
rechner.analyt(steuer.Intens_init, steuer.kappa, gitter.i_max, gitter.x, gitter.delta_x)
ausgabe.schirm_ausgabe(gitter.i_max, gitter.x, rechner.Intens, rechner.Intens_analyt)
ausgabe.datei_ausgabe(steuer.ausgabe_datei, gitter.i_max, gitter.x, rechner.Intens, rechner.Intens_analyt,steuer.kappa,rechner.Intens_absorbiert)
ausgabe.graphik_ausgabe(steuer.graphik_datei,gitter.i_max, gitter.x, steuer.kappa, rechner.Intens, rechner.Intens_analyt)
#*************************************************************
# Berechnung der Endzeit des Programmes mit:
# a) datetime
# b) time
# und Konvertieren der Endzeit zu einem String "datum_zeit"
#*************************************************************
lt_end = time.localtime()
jahr, monat, tag, stunde, minute, sekunde  = lt_end[0:6]
datum_zeit = "Datum: "+str(tag)+"."+str(monat)+"."+str(jahr)+"\n"+"Zeit: "+str(stunde)+":"+str(minute)+":"+str(sekunde)
dt_end = datetime.datetime.now()

#*************************************************************
# Berechnung der Rechendauer mit dem Zeitdifferenzoperator 
# des Moduls datetime
#*************************************************************
dauer = dt_end - dt_start

#*************************************************************
# Schreiben von Datum und Zeit des Programmendes und der 
# Rechendauer in die Logdatei 
#*************************************************************
fobj_log.write("Ende: "+ "\n" +datum_zeit + "\n")
fobj_log.write("Rechendauer: "+ "\n" + str(dauer))

fobj_log.close()

#*************************************************************
#Programmende
#*************************************************************


